@@ -7,7 +7,7 @@ from functools import cache
 import itertools
 import math
 
-from typing import Any, Callable, Sequence
+from typing import Any, Callable, Generator, Sequence
 
 
 @cache
@@ -48,13 +48,17 @@ def __getattr__(key: str):
     raise AttributeError(key)
 
 
-def bernoulli(numerator: int, denominator: int, /) -> 'icepool.Die':
+def bernoulli(n: int, d: int, /) -> 'icepool.Die':
     """A `Die` that rolls `True` with probability `n / d`, and `False` otherwise.
 
-    The `Die` will have both `True` and `False` as outcomes even if one has
-    zero quantity.
+    If `n == 0` or `n == d` the result will have only one outcome.
     """
-    return icepool.Die({False: denominator - numerator, True: numerator})
+    data = {}
+    if n != d:
+        data[False] = d - n
+    if n != 0:
+        data[True] = n
+    return icepool.Die(data)
 
 
 coin = bernoulli
@@ -150,7 +154,10 @@ def align_range(*dice) -> tuple['icepool.Die', ...]:
     return tuple(die.set_outcomes(outcomes) for die in dice)
 
 
-def reduce(func: Callable[[Any, Any], Any], dice, *, initial=None):
+def reduce(func: Callable[[Any, Any], Any],
+           dice,
+           *,
+           initial=None) -> 'icepool.Die':
     """Applies a function of two arguments cumulatively to a sequence of dice.
 
     Analogous to
@@ -168,7 +175,7 @@ def reduce(func: Callable[[Any, Any], Any], dice, *, initial=None):
     # Conversion to dice is not necessary since apply() takes care of that.
     iter_dice = iter(dice)
     if initial is not None:
-        result = initial
+        result = icepool.Die([initial])
     else:
         result = next(iter_dice)
     for die in iter_dice:
@@ -176,7 +183,10 @@ def reduce(func: Callable[[Any, Any], Any], dice, *, initial=None):
     return result
 
 
-def accumulate(func: Callable[[Any, Any], Any], dice, *, initial=None):
+def accumulate(func: Callable[[Any, Any], Any],
+               dice,
+               *,
+               initial=None) -> Generator['icepool.Die', None, None]:
     """Applies a function of two arguments cumulatively to a sequence of dice, yielding each result in turn.
 
     Analogous to
@@ -199,7 +209,7 @@ def accumulate(func: Callable[[Any, Any], Any], dice, *, initial=None):
     # Conversion to dice is not necessary since apply() takes care of that.
     iter_dice = iter(dice)
     if initial is not None:
-        result = initial
+        result = icepool.Die([initial])
     else:
         try:
             result = next(iter_dice)
@@ -239,6 +249,10 @@ def apply(func: Callable, *dice) -> 'icepool.Die':
         A `Die` constructed from the outputs of `func` and the product of the
         quantities of the dice.
     """
+    if not callable(func):
+        raise TypeError(
+            'The first argument must be callable. Did you forget to provide a function?'
+        )
     if len(dice) == 0:
         return icepool.Die([func()])
     dice = tuple(icepool.Die([die]) for die in dice)
@@ -255,22 +269,64 @@ def apply(func: Callable, *dice) -> 'icepool.Die':
     return icepool.Die(final_outcomes, final_quantities)
 
 
-def apply_sorted(func: Callable, *dice) -> 'icepool.Die':
-    """Applies `func(lowest_outcome, next_lowest_outcome...)` for all sorted joint outcomes of the dice.
+class apply_sorted():
+    """This is really a function implemented as a class.
 
-    This is more efficient than `apply()` but still not very efficient.
-    Use `OutcomeCountEvaluator` instead if at all possible.
-
-    Args:
-        func: A function that takes one argument per input `Die` and returns an
-            argument to `Die()`.
-        *dice: Any number of dice (or objects convertible to dice).
-            `func` will be called with all sorted joint outcomes of `dice`,
-            with one argument per die. All outcomes must be totally orderable.
-
-    Returns:
-        A `Die` constructed from the outputs of `func` and the weight of rolling
-        the corresponding sorted outcomes.
+    See the "constructor" for details.
     """
-    pool = icepool.Pool(dice)
-    return icepool.enumerate_sorted(pool).sub(func, star=1)
+
+    def __new__(cls, func: Callable, *dice) -> 'icepool.Die':  # type: ignore
+        """Applies `func(lowest_outcome, next_lowest_outcome...)` for all sorted joint outcomes of the dice.
+
+        Not actually a constructor.
+
+        This is more efficient than `apply()` but still not very efficient.
+        Use `OutcomeCountEvaluator` instead if at all possible.
+
+        You can use `apply_sorted[]` to only see outcomes at particular sorted indexes.
+        For example, `apply_sorted[-2:](func, *dice)` would give the two highest
+        outcomes to `func()`. This is more efficient than selecting outcomes inside
+        `func`.
+
+        Args:
+            func: A function that takes one argument per input `Die` and returns an
+                argument to `Die()`.
+            *dice: Any number of dice (or objects convertible to dice).
+                `func` will be called with all sorted joint outcomes of `dice`,
+                with one argument per die. All outcomes must be totally orderable.
+
+        Returns:
+            A `Die` constructed from the outputs of `func` and the weight of rolling
+            the corresponding sorted outcomes.
+        """
+        if not callable(func):
+            raise TypeError(
+                'The first argument must be callable. Did you forget to provide a function?'
+            )
+        pool = icepool.Pool(dice)
+        return icepool.enumerate_sorted(pool).sub(func, star=1)
+
+    def __class_getitem__(cls,
+                          sorted_roll_counts: int | slice | tuple[int, ...],
+                          /) -> Callable[..., 'icepool.Die']:
+        """Implements `[]` syntax for `apply_sorted`."""
+        if isinstance(sorted_roll_counts, int):
+
+            def result(func: Callable, *dice) -> 'icepool.Die':
+                if not callable(func):
+                    raise TypeError(
+                        'The first argument must be callable. Did you forget to provide a function?'
+                    )
+                die = icepool.Pool(dice)[sorted_roll_counts]
+                return die.sub(func)
+        else:
+
+            def result(func: Callable, *dice) -> 'icepool.Die':
+                if not callable(func):
+                    raise TypeError(
+                        'The first argument must be callable. Did you forget to provide a function?'
+                    )
+                pool = icepool.Pool(dice)[sorted_roll_counts]
+                return icepool.enumerate_sorted(pool).sub(func, star=1)
+
+        return result
